==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/hu.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// Translated by Zsozso - zsozso@internews.hu
// $Id: hu.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Rendszer Informci';

$text['vitals']         = 'A Rendszer Alapvet Informcii';
$text['hostname']       = 'Hostnv';
$text['ip']             = 'Figyelt IP';
$text['kversion']       = 'Kernel Verzi';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Pillanatnyi felhasznlk';
$text['loadavg']        = 'Terhelsi tlag';

$text['hardware']       = 'Hardware Informci';
$text['numcpu']         = 'Processzor';
$text['cpumodel']       = 'Modell';
$text['mhz']            = 'Chip MHz';
$text['cache']          = 'Cache Mret';
$text['bogomips']       = 'Rendszer Bogomips';
$text['usb']            = 'USB Eszkzk';
$text['pci']            = 'PCI Eszkzk';
$text['ide']            = 'IDE Eszkzk';
$text['scsi']           = 'SCSI Eszkzk';

$text['netusage']       = 'Hl Hasznlat';
$text['device']         = 'Eszkz';
$text['received']       = 'Fogadott';
$text['sent']           = 'Kldtt';
$text['hibk']          = 'Err/Drop';

$text['connections']    = 'Ltestett Hlzati Kapcsolatok';

$text['memusage']       = 'Memria Hasznlat';
$text['phymem']         = 'Fizikai Memria';
$text['swap']           = 'Lemez Swap';

$text['fs']             = 'Csatlakoztatott File Rendszerek';
$text['mount']          = 'Mount';
$text['partition']      = 'Partcik';

$text['percent']        = 'Szzalkos Hasznlat';
$text['type']           = 'Tpus';
$text['free']           = 'Szabad';
$text['used']           = 'Hasznlt';
$text['size']           = 'Mret';
$text['totals']         = 'sszesen';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nincs';

$text['capacity']       = 'Kapacts'; 

$text['template']       = 'Sablon';
$text['language']       = 'Nyelv';
$text['submit']         = 'Mehet';
$text['created']        = 'Kszlt:';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'nap';
$text['hours']          = 'ra';
$text['minutes']        = 'perc';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/hu.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// Translated by Zsozso - zsozso@internews.hu
// $Id: hu.php,v 1.12 2004/08/30 15:51:26 webbie Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Rendszer Informci';

$text['vitals']         = 'A Rendszer Alapvet Informcii';
$text['hostname']       = 'Hostnv';
$text['ip']             = 'Figyelt IP';
$text['kversion']       = 'Kernel Verzi';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Pillanatnyi felhasznlk';
$text['loadavg']        = 'Terhelsi tlag';

$text['hardware']       = 'Hardware Informci';
$text['numcpu']         = 'Processzor';
$text['cpumodel']       = 'Modell';
$text['cpuspeed']       = 'Chip MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache Mret';
$text['bogomips']       = 'Rendszer Bogomips';

$text['pci']            = 'PCI Eszkzk';
$text['ide']            = 'IDE Eszkzk';
$text['scsi']           = 'SCSI Eszkzk';
$text['usb']            = 'USB Eszkzk';

$text['netusage']       = 'Hl Hasznlat';
$text['device']         = 'Eszkz';
$text['received']       = 'Fogadott';
$text['sent']           = 'Kldtt';
$text['hibk']          = 'Err/Drop';

$text['connections']    = 'Ltestett Hlzati Kapcsolatok';

$text['memusage']       = 'Memria Hasznlat';
$text['phymem']         = 'Fizikai Memria';
$text['swap']           = 'Lemez Swap';

$text['fs']             = 'Csatlakoztatott File Rendszerek';
$text['mount']          = 'Mount';
$text['partition']      = 'Partcik';

$text['percent']        = 'Szzalkos Hasznlat';
$text['type']           = 'Tpus';
$text['free']           = 'Szabad';
$text['used']           = 'Hasznlt';
$text['size']           = 'Mret';
$text['totals']         = 'sszesen';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'nincs';

$text['capacity']       = 'Kapacts'; 

$text['template']       = 'Sablon';
$text['language']       = 'Nyelv';
$text['submit']         = 'Mehet';
$text['created']        = 'Kszlt:';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'nap';
$text['hours']          = 'ra';
$text['minutes']        = 'perc';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
